@@ -2,6 +2,9 @@ from typing import Any, Callable, Optional
 
 
 class Depends():
+    """
+    Dependency registration class
+    """
     def __init__(self, obj: Optional[Callable[..., Any]] = None) -> None:
         self.obj = obj
     
